closed_form_RNA: Closed-form prediction for RNAmf model

View source: R/predict.RNAmf.R

closed_form_RNAR Documentation

Closed-form prediction for RNAmf model

Description

The function computes the closed-form posterior mean and variance for the RNAmf model both at the fidelity levels used in model fitting using the chosen kernel.

Usage

closed_form_RNA(fits, x, kernel, XX = NULL, pseudo_yy = NULL)

Arguments

fits

A fitted GP object from RNAmf.

x

A vector or matrix of new input locations to predict.

kernel

A character specifying the kernel type to be used. Choices are "sqex"(squared exponential kernel), "matern1.5"(Matern kernel with \nu=1.5), or "matern2.5"(Matern kernel with \nu=2.5). Default is "sqex".

XX

A list containing a pseudo-complete inputs X_star(\left\{\mathcal{X}^*_l\right\}_{l=1}^{L}), an original inputs X_list(\left\{\mathcal{X}_l\right\}_{l=1}^{L}), and a pseudo inputs X_tilde(\left\{\widetilde{\mathcal{X}}_l\right\}_{l=1}^{L}) for non-nested design.

pseudo_yy

A list containing a pseudo-complete outputs y_star(\left\{\mathbf{y}^*_l\right\}_{l=1}^{L}), an original outputs y_list(\left\{\mathbf{y}_l\right\}_{l=1}^{L}), and a pseudo outputs y_tilde(\left\{\widetilde{\mathbf{y}}_l\right\}_{l=1}^{L}) imputed by imputer_RNA.

Value

A list of predictive posterior mean and variance for each level containing:

  • mu: A list of predictive posterior mean at each fidelity level.

  • sig2: A list of predictive posterior variance at each fidelity level.


RNAmf documentation built on May 5, 2026, 9:06 a.m.

Related to closed_form_RNA in RNAmf...