imputer_RNA: Imputation step in stochastic EM for the non-nested RNA Model

View source: R/imputer_RNA.R

imputer_RNAR Documentation

Imputation step in stochastic EM for the non-nested RNA Model

Description

The function performs the imputation step of the stochastic EM algorithm for the RNA model when the design is not nested. The function generates pseudo outputs \widetilde{\mathbf{y}}_l at pseudo inputs \widetilde{\mathcal{X}}_l.

Usage

imputer_RNA(XX, yy, kernel=kernel, pred1, fits)

Arguments

XX

A list of design sets for all fidelity levels, containing X_star, X_list, and X_tilde.

yy

A list of current observed and pseudo-responses, containing y_star, y_list, and y_tilde.

kernel

A character specifying the kernel type to be used. Choices are "sqex"(squared exponential), "matern1.5", or "matern2.5".

pred1

Predictive results for the lowest fidelity level f_1. It should include cov obtained by setting cov.out=TRUE.

fits

A fitted GP object from RNAmf.

Details

The imputer_RNA function then imputes the corresponding pseudo outputs \widetilde{\mathbf{y}}_l = f_l(\widetilde{\mathcal{X}}_l) by drawing samples from the conditional normal distribution, given fixed parameter estimates and previous-level outputs Y_{l}^{*(m-1)} for each l, at the m-th iteration of the EM algorithm.

Value

An updated yy list containing:

  • y_star: An updated pseudo-complete outputs \mathbf{y}^*_l.

  • y_list: An original outputs \mathbf{y}_l.

  • y_tilde: A newly imputed pseudo outputs \widetilde{\mathbf{y}}_l.


RNAmf documentation built on May 5, 2026, 9:06 a.m.

Related to imputer_RNA in RNAmf...