View source: R/predict.RNAmf.R
| closed_form_RNA | R Documentation |
The function computes the closed-form posterior mean and variance for the RNAmf model both at the fidelity levels used in model fitting using the chosen kernel.
closed_form_RNA(fits, x, kernel, XX = NULL, pseudo_yy = NULL)
fits |
A fitted GP object from |
x |
A vector or matrix of new input locations to predict. |
kernel |
A character specifying the kernel type to be used. Choices are |
XX |
A list containing a pseudo-complete inputs |
pseudo_yy |
A list containing a pseudo-complete outputs |
A list of predictive posterior mean and variance for each level containing:
mu: A list of predictive posterior mean at each fidelity level.
sig2: A list of predictive posterior variance at each fidelity level.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.