| imputer_RNA | R Documentation |
The function performs the imputation step of the stochastic EM algorithm for the RNA model when the design is not nested.
The function generates pseudo outputs \widetilde{\mathbf{y}}_l at pseudo inputs \widetilde{\mathcal{X}}_l.
imputer_RNA(XX, yy, kernel=kernel, pred1, fits)
XX |
A list of design sets for all fidelity levels, containing |
yy |
A list of current observed and pseudo-responses, containing |
kernel |
A character specifying the kernel type to be used. Choices are |
pred1 |
Predictive results for the lowest fidelity level |
fits |
A fitted GP object from |
The imputer_RNA function then imputes the corresponding pseudo outputs
\widetilde{\mathbf{y}}_l = f_l(\widetilde{\mathcal{X}}_l)
by drawing samples from the conditional normal distribution,
given fixed parameter estimates and previous-level outputs Y_{l}^{*(m-1)} for each l,
at the m-th iteration of the EM algorithm.
An updated yy list containing:
y_star: An updated pseudo-complete outputs \mathbf{y}^*_l.
y_list: An original outputs \mathbf{y}_l.
y_tilde: A newly imputed pseudo outputs \widetilde{\mathbf{y}}_l.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.